# The Ultimate Python Project Template

This repo serves as the ultimate Python project template.
In addition to providing a Python project directory 
structure, this repo also features some nice quality of
life features including automated testing and publishing
through GitHub Actions. Likewise, it includes automated
documentation through Read the Docs. 

---

Note: the pip package generated by this repo does nothing
and only serves as proof that the template works. That said,
you could theoretically use the functions in it.
